@@ -1,10 +1,12 @@
+##
+# This module requires Metasploit: https://metasploit.com/download
+# Current source: https://github.com/rapid7/metasploit-framework
+##
 
-require 'msf/core'
 require 'metasploit/framework/login_scanner/ipboard'
 require 'metasploit/framework/credential_collection'
 
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::HttpClient
   include Msf::Auxiliary::Report
   include Msf::Auxiliary::AuthBrute
@@ -23,7 +25,7 @@ class MetasploitModule < Msf::Auxiliary
 
     register_options([
         OptString.new('TARGETURI', [true, "The directory of the IP Board install", "/forum/"]),
-      ], self.class)
+      ])
   end
 
   def run_host(ip)
@@ -77,5 +79,4 @@ class MetasploitModule < Msf::Auxiliary
     end
 
   end
-
 end
