@@ -1,11 +1,10 @@
 # -*- coding: binary -*-
 
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/exploit/powershell'
 
 class MetasploitModule < Msf::Exploit::Remote
@@ -57,7 +56,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'References'       => [
         [ 'CVE', '1999-0504'], # Administrator with no password (since this is the default)
         [ 'OSVDB', '3106'],
-        [ 'URL', 'http://www.accuvant.com/blog/2012/11/13/owning-computers-without-shell-access' ],
+        [ 'URL', 'https://www.optiv.com/blog/owning-computers-without-shell-access' ],
         [ 'URL', 'http://sourceforge.net/projects/smbexec/' ],
         [ 'URL', 'http://technet.microsoft.com/en-us/sysinternals/bb897553.aspx' ]
       ]
@@ -65,7 +64,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     register_options([
       OptBool.new('DryRun',[false,'Prints the powershell command that would be used',false]),
-    ], self.class)
+    ])
   end
 
   def exploit
@@ -97,6 +96,5 @@ class MetasploitModule < Msf::Exploit::Remote
       end
     end
   end
-
 end
 
