@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 include Msf::Auxiliary::Report
 
 class MetasploitModule < Msf::Post
@@ -187,5 +185,4 @@ class MetasploitModule < Msf::Post
   def print_error(msg='')
     super("#{session.session_host} - #{msg}")
   end
-
 end
